/**
 *
 * @author Wei-Ming Wu
 *
 *
 * Copyright 2013 Wei-Ming Wu
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 *
 */
package net.sf.rubycollect4j.iter;

import java.util.Iterator;
import java.util.Map.Entry;
import java.util.NoSuchElementException;

import static net.sf.rubycollect4j.RubyCollections.newPair;

/**
 * 
 * EachWithIndexIterator iterates each elements with its index.
 * 
 * @param <E>
 *          the type of the elements
 */
public final class EachWithIndexIterator<E> implements
    Iterator<Entry<E, Integer>> {

  private final Iterator<E> iter;
  private final int[] index = new int[] { 0 };

  /**
   * The constructor of the EachWithIndexIterator.
   * 
   * @param iter
   *          an Iterator
   */
  public EachWithIndexIterator(Iterator<E> iter) {
    this.iter = iter;
  }

  private Entry<E, Integer> nextElement() {
    Entry<E, Integer> element = newPair(iter.next(), index[0]);
    index[0]++;
    return element;
  }

  @Override
  public boolean hasNext() {
    return iter.hasNext();
  }

  @Override
  public Entry<E, Integer> next() {
    if (!hasNext()) {
      throw new NoSuchElementException();
    }
    return nextElement();
  }

  @Override
  public void remove() {
    throw new UnsupportedOperationException();
  }

}
